Changes
=======

0.4 (2024-02-12)
----------------

- Adopt Settings UI changes from ``cone.app``.
  [rnix]


0.3 (2023-09-28)
----------------

- Tokens can be bulk deleted.
  [lenadax]

- Tokens can be created from scanned value.
  [rnix]


0.2 (2023-09-27)
----------------

- Actually upload package to pypi.
  [rnix]


0.1 (2023-09-27)
----------------

- Initial work.
  [rnix, toalba, lenadax]
